@@ -12,6 +12,7 @@ class TestDataAnalysisPipeline(PipelineTest):
         dap.execute()
 
         assert dap.result.result == self.ds_one_analysis_result
+        self.assert_all_pipeline_operations_have_pipeline(dap)
 
     def test_analysis_pipeline_output(self):
         options = AnalysisOptions(analysis_from_source, out_path=self.csv_path_output)
@@ -22,6 +23,7 @@ class TestDataAnalysisPipeline(PipelineTest):
             result_from_file = int(f.read())
 
         assert result_from_file == self.ds_one_analysis_result
+        self.assert_all_pipeline_operations_have_pipeline(dap)
 
     def test_create_and_run_analysis_pipeline_from_merge_pipeline(self):
         dmp = self.create_merge_pipeline()
@@ -29,6 +31,7 @@ class TestDataAnalysisPipeline(PipelineTest):
         dap.execute()
 
         assert dap.result.result == self.ds_one_and_two_analysis_result
+        self.assert_ordered_pipeline_operations(dap, [dmp, dap])
 
     def test_create_and_run_analysis_pipeline_from_transformation_pipeline(self):
         dtp = self.create_transformation_pipeline()
@@ -36,6 +39,7 @@ class TestDataAnalysisPipeline(PipelineTest):
         dap.execute()
 
         assert dap.result.result == self.ds_one_transformed_analysis_result
+        self.assert_ordered_pipeline_operations(dap, [dtp, dap])
 
     def test_create_and_run_analysis_pipeline_from_generation_pipeline(self):
         dgp = self.create_generator_pipeline()
@@ -43,6 +47,7 @@ class TestDataAnalysisPipeline(PipelineTest):
         dap.execute()
 
         assert dap.result.result == self.ds_one_generated_analysis_result
+        self.assert_ordered_pipeline_operations(dap, [dgp, dap])
 
     def test_create_and_run_multiple_analysis_pipelines_from_same_transformation_pipeline(self):
         dtp = self.create_transformation_pipeline()
@@ -65,6 +70,8 @@ class TestDataAnalysisPipeline(PipelineTest):
         assert dap1.result.result == self.ds_one_transformed_analysis_result
         assert dap2.result.result == self.ds_one_transformed_analysis_result_offset_10
         assert th.COUNTER == counter_value + 1  # transform operation called only once
+        self.assert_ordered_pipeline_operations(dap1, [dtp, dap1])
+        self.assert_ordered_pipeline_operations(dap2, [dtp, dap2])
 
     def test_create_and_run_multiple_analysis_pipelines_from_same_transformation_pipeline_with_always_rerun(self):
         dtp = self.create_transformation_pipeline(always_rerun=True)
@@ -86,4 +93,6 @@ class TestDataAnalysisPipeline(PipelineTest):
         assert dap1.operations[0].data_source is dap2.operations[0].data_source
         assert dap1.result.result == self.ds_one_transformed_analysis_result
         assert dap2.result.result == self.ds_one_transformed_analysis_result_offset_10
-        assert th.COUNTER == counter_value + 2  # transform operation called twice as always rerun
\ No newline at end of file
+        assert th.COUNTER == counter_value + 2  # transform operation called twice as always rerun
+        self.assert_ordered_pipeline_operations(dap1, [dtp, dap1])
+        self.assert_ordered_pipeline_operations(dap2, [dtp, dap2])
\ No newline at end of file
